==> mls-0.1.tar.gz: mls-0.1/src/ZipReader.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Byoungyoung, La                                 *
 *   la9527@yahoo.co.kr                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#ifndef ZipReader_h_
#define ZipReader_h_
 
#include "define.h"
#include "mls.h"
#include "reader.h"
#include "file.h"
#include "TargzUtil.h"

namespace MLS
{
	class ZipReader:public Reader
	{
		public:
			ZipReader();
			~ZipReader();
			
			void	SetZipFile(const string& sDir, const string& sFilename)
			{
				m_sDir = sDir; m_sFilename = sFilename;
			}
			
			virtual int  Copy(vector<string>& tCpyData, string& sTarget);
			virtual int  Remove(vector<string>& tRemoveData);
		
			virtual bool Init(const std::string &path = "");
			virtual bool Next();
			virtual bool GetInfo(File& tFile);
			virtual void Destroy();
			virtual bool isRoot();
			
		private:
			TargzUtil*			m_pTargzUtil;
			vector<MLS::File*>	m_Filelist;	
			uint				m_CurrentData;
			string				m_currentPath;
			string				m_ZipCurrentDir;
			int					m_Count;
			
			string				m_sDir;
			string				m_sFilename;
	};
};

#endif

==> mls-0.2.tar.gz: mls-0.2/src/ZipReader.h <==
/* *************************************************************************
 *   Copyright (C) 2004 by Byoungyoung, La                                 *
 *   la9527@yahoo.co.kr                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ************************************************************************* */
 
///	\file	ZipReader.h
///	\brief	ZipReader.h	
#ifndef ZipReader_h_
#define ZipReader_h_
 
#include "define.h"
#include "mls.h"
#include "dialog.h"
#include "reader.h"
#include "file.h"
#include "TargzUtil.h"

namespace MLS
{
	///	\brief	zip file reader
	class ZipReader:public Reader
	{
		public:
			ZipReader();
			~ZipReader();
			
			///	\brief	zipfile name을 설정한다.
			///	\param	sDir		zipfile이 위치하는 directory
			///	\param	sFilename	zipfile name
			void	SetZipFile(const string& sDir, const string& sFilename)
			{
				m_sDir = sDir; m_sFilename = sFilename;
			}
			
			virtual int  Copy(vector<string>& tCpyData, string& sTarget);
			virtual int  Remove(vector<string>& tRemoveData);
			virtual int  View(File& tFile, const string& sTmpDir);
		
			virtual bool Init(const std::string &path = "");
			virtual bool Next();
			virtual bool GetInfo(File& tFile);
			virtual void Destroy();
			virtual bool isRoot();
			
			
		private:
			TargzUtil*			m_pTargzUtil;	///< targz util object
			vector<MLS::File*>	m_Filelist;		///< filelist 벡터
			uint				m_CurrentData;	///< 현재 선택된 파일 index
			string				m_currentPath;	///< current path?
			string				m_ZipCurrentDir;///< zip current dir?
			int					m_Count;		///< count ?
			
			string				m_sDir;			///< zipfile이 있는 direictory
			string				m_sFilename;	///< zipfile name
	};
};

#endif
